/*-
 * Copyright (c) 2013 Devin Teske <dteske@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#ifndef _DIALOG_H_
#define _DIALOG_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <sys/types.h>

#include "dialogrc.h"

#define DIALOG_DEBUG	0	/* Show debug when spawning [X]dialog(1) */

/* [X]dialog(1) characteristics */
#define DIALOG		"dialog"
#define XDIALOG		"Xdialog"
#define PROMPT_MAX	16384
#define ENV_DIALOG	"DIALOG"
#define ENV_USE_COLOR	"USE_COLOR"
#define ENV_XDIALOG_HIGH_DIALOG_COMPAT	"XDIALOG_HIGH_DIALOG_COMPAT"
extern uint8_t dialog_test;
extern uint8_t use_dialog;
extern uint8_t use_xdialog;
extern uint8_t use_color;
extern char dialog[];

/* [X]dialog(1) functionality */
extern int dheight, dwidth;
extern char *title, *backtitle;

/* Function prototypes */
int		dialog_maxcols(void);
int		dialog_maxrows(void);
char *		dialog_prompt_lastline(char *prompt, uint8_t nlstate);
unsigned int	dialog_prompt_longestline(const char *prompt, uint8_t nlstate);
unsigned int	dialog_prompt_numlines(const char *prompt, uint8_t nlstate);
uint8_t		dialog_prompt_nlstate(const char *prompt);
int		dialog_prompt_wrappedlines(char *prompt, int ncols,
		    uint8_t nlstate);
int		dialog_spawn_gauge(char *init_prompt, pid_t *pid);

#ifdef __cplusplus
}
#endif

#endif /* !_DIALOG_H_ */
